@@ -29,24 +29,25 @@ class CachedArray(abstract.FileArray):
         '''**Initialization**
 
     :Parameters:
-    
+
         array: numpy array
-            The array to be stored on disk in a temporary file.        
-    
+            The array to be stored on disk in a temporary file.
+
     **Examples:**
-    
+
     >>> f = CachedArray(numpy.array([1, 2, 3, 4, 5]))
     >>> f = CachedArray(numpy.ma.array([1, 2, 3, 4, 5]))
 
         '''
         super().__init__()
-        
+
         # ------------------------------------------------------------
         # Use mkstemp because we want to be responsible for deleting
         # the temporary file when done with it.
         # ------------------------------------------------------------
-        _partition_dir = mkdtemp(prefix='cf_cachedarray_', dir=CONSTANTS['TEMPDIR'])
-        fd, _partition_file = mkstemp(prefix='cf_cachedarray_', suffix='.npy', 
+        _partition_dir = mkdtemp(
+            prefix='cf_cachedarray_', dir=CONSTANTS['TEMPDIR'])
+        fd, _partition_file = mkstemp(prefix='cf_cachedarray_', suffix='.npy',
                                       dir=_partition_dir)
         close(fd)
 
@@ -81,12 +82,11 @@ class CachedArray(abstract.FileArray):
                 # Array is not a masked array.
                 numpy_save(_partition_file, array)
 
-
     def __getitem__(self, indices):
         '''x.__getitem__(indices) <==> x[indices]
 
     Returns a numpy array.
-        
+
         '''
         array = numpy_load(self._partition_file)
 
@@ -103,14 +103,12 @@ class CachedArray(abstract.FileArray):
         # Return the numpy array
         return array
 
-    
     def __str__(self):
         '''x.__str__() <==> str(x)
 
         '''
         return '%s in %s' % (self.shape, self._partition_file)
 
-
     # ----------------------------------------------------------------
     # Attributes
     # ----------------------------------------------------------------
@@ -121,7 +119,6 @@ class CachedArray(abstract.FileArray):
         '''
         return self._get_component('_partition_dir')
 
-
     @property
     def _partition_file(self):
         '''TODO
@@ -130,4 +127,4 @@ class CachedArray(abstract.FileArray):
         return self._get_component('_partition_file')
 
 
-#--- End: class
+# --- End: class
